@@ -30,7 +30,7 @@ class InvalidEncryptionKeyError(ValueError):
 
 class Settings(BaseSettings):
     environment: Environment = Environment.DEVELOPMENT
-    log_level: str = "DEBUG"
+    log_level: str = "INFO"
     unit_tests: bool = False
     sentry_dsn: Optional[str] = None
     root_domain: str = "localhost:8000"
@@ -47,6 +47,7 @@ class Settings(BaseSettings):
     database_password: Optional[str] = None
     database_name: Optional[str] = "fief.db"
     database_location: DirectoryPath = Path.cwd()
+    database_pool_recycle_seconds: int = 600
 
     redis_url: str = "redis://localhost:6379"
 
